
[![GitHub Release](https://img.shields.io/github/v/release/mannlabs/py-lmd?logoColor=green&color=brightgreen)](https://github.com/MannLabs/py-lmd/releases)
![Versions](https://img.shields.io/badge/python-3.9_%7C_3.10_%7C_3.11_%7C_3.12-brightgreen)
[![License](https://img.shields.io/badge/license-Apache-brightgreen)](https://github.com/MannLabs/py-lmd/blob/main/LICENSE)
[![Python package](https://github.com/MannLabs/py-lmd/actions/workflows/python-package.yml/badge.svg?branch=main)](https://github.com/MannLabs/py-lmd/actions/workflows/python-package.yml)
[![Docs](https://img.shields.io/website?url=https%3A%2F%2Fmannlabs.github.io/py-lmd/index.html)](https://mannlabs.github.io/py-lmd/index.html)
[![PyPI version](https://img.shields.io/pypi/v/py-lmd.svg)](https://pypi.org/project/py-lmd/)
[![PyPI Downloads](https://static.pepy.tech/badge/py-lmd)](https://pepy.tech/projects/py-lmd)


![logo](https://github.com/MannLabs/py-lmd/assets/15019107/e7c619a2-69c9-4cb6-8723-fab94c8d3558)

Read, create and write cutting data for the Leica LMD6 & LMD7 microscope.
Build reproducible workflows to calibrate, import SVG files and convert single-cell segmentation masks.


Installation
============
The py-lmd library can be installed via pip.
py-lmd has been tested with **Python 3.9, 3.10, 3.11 and 3.12**.

```
pip install py-lmd
```

Documentation
=============
The current documentation can be found under https://mannlabs.github.io/py-lmd/html/index.html.

Citing our Work
=================

py-lmd was developed by Georg Wallmann, Sophia Mädler and Niklas Schmacke in the labs of Veit Hornung and Matthias Mann. If you use our code please cite the [following manuscript](https://www.biorxiv.org/content/10.1101/2023.06.01.542416v1):

SPARCS, a platform for genome-scale CRISPR screening for spatial cellular phenotypes
Niklas Arndt Schmacke, Sophia Clara Maedler, Georg Wallmann, Andreas Metousis, Marleen Berouti, Hartmann Harz, Heinrich Leonhardt, Matthias Mann, Veit Hornung
bioRxiv 2023.06.01.542416; doi: https://doi.org/10.1101/2023.06.01.542416

## Contributing

If you like this software, consider giving us a star to boost our visibility! For detailed guidelines on how to contribute, please refer to our [contributing guide](CONTRIBUTING.md).

We welcome all types of contributions! You can:

- Post a new [issue](https://github.com/MannLabs/py-lmd/issues) if you encounter a bug or have a feature request.
- Clone the repository, create a new branch, and submit a [pull request](https://github.com/MannLabs/py-lmd/pulls).
